pub struct FileDetail {
pub name: String,
pub uuid: Uuid,
pub path: AbsolutePath,
pub abspath: AbsolutePath,
pub latest_revision: Option<Revision>,
pub current_revision: Option<Revision>,
pub revisions: Revisions,
}Expand description
Detailed file information.
Fields
name: StringFilename.
uuid: UuidId of the file.
path: AbsolutePathPath to the folder containing this file.
abspath: AbsolutePathAbsolute path to the folder containing this file, whatever that means.
latest_revision: Option<Revision>The upcoming revision.
Probably never has a state of Completed.
current_revision: Option<Revision>The optional current revision, which always should have a state of Completed.
revisions: RevisionsEarlier revisions.
Implementations
Sourceimpl FileDetail
impl FileDetail
Sourcepub fn last_upload_complete(&self) -> bool
pub fn last_upload_complete(&self) -> bool
Check if latest_revision is None (otherwise it probably is Incomplete or
Corrupted) and if current_revision has a state of Completed.